Vault

Trait Vault 

pub trait Vault {
    // Required methods
    fn new(
        public: Option<PublicKey>,
        private: Option<PrivateKey>,
    ) -> Result<Self>
       where Self: Sized;
    fn create(
        &self,
        password: SecretSlice<u8>,
        data: &mut [u8],
    ) -> Result<String>;
    fn view(
        &self,
        password: &[u8],
        data: &[u8],
        fingerprint: &str,
    ) -> Result<String>;
}
Trait defining the vault operations for different key types

Required Methods

fn new(public: Option<PublicKey>, private: Option<PrivateKey>) -> Result<Self>
where Self: Sized,

Creates a new vault instance with the given keys

Errors

Returns an error if the provided keys are invalid or mismatched.

fn create(&self, password: SecretSlice<u8>, data: &mut [u8]) -> Result<String>

Encrypts data and creates a vault string

Errors

Returns an error if encryption fails.

fn view( &self, password: &[u8], data: &[u8], fingerprint: &str, ) -> Result<String>

Decrypts vault contents

Errors

Returns an error if decryption fails or the fingerprint is invalid.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors